/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 


Table 2. Local Swing riots and the outcome of the 1831 and 1830 elections. Alternative measures of local Swing riots and spatial correlation.

Special programs used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.


********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Regression results reported Table 2, panel A 

The cutoff values are
					20km	 50Km	100km	200km
Latitude  cutoff	0.18	 0.45    0.9	  1.8
Longitude cutoff	0.30	 0.75    1.5	   3

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 


foreach lname of var constriots1 constriots10 constriots20 constriots30  constriots50 difriot_75_50 {
               
reg share1831 `lname' $baseline, robust b

							
        }



		foreach lname of var constriots1 constriots10 constriots20 constriots30  constriots50 difriot_75_50 {
                gen const=1
				gen cutoff1=0.18
				gen cutoff2=0.30

x_ols latitude longitude cutoff1 cutoff2 share1831  const `lname'  $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots

drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

							
        }


		

		foreach lname of var constriots1 constriots10 constriots20 constriots30  constriots50 difriot_75_50 {
                gen const=1
				gen cutoff1=0.45
				gen cutoff2=0.75

x_ols latitude longitude cutoff1 cutoff2 share1831  const `lname'  $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots

drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

							
        }

		foreach lname of var constriots1 constriots10 constriots20 constriots30  constriots50 difriot_75_50 {
                gen const=1
				gen cutoff1=0.9
				gen cutoff2=1.5

x_ols latitude longitude cutoff1 cutoff2 share1831  const `lname'  $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots

drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

							
        }


				foreach lname of var constriots1 constriots10 constriots20 constriots30  constriots50 difriot_75_50 {
                gen const=1
				gen cutoff1=1.8
				gen cutoff2=3.0

x_ols latitude longitude cutoff1 cutoff2 share1831  const `lname'  $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots

drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

							
        }


/********************************************************************************************************************************************************************

Regression results reported Table 2, panel B 


The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75   

NB: x_ols report OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 


foreach lname of var constriots1 constriots10 constriots20 constriots30  constriots50 difriot_75_50 {
               
reg share1830 `lname' $baseline, robust b
display e(r2_a)  
							
        }



		foreach lname of var constriots1 constriots10 constriots20 constriots30  constriots50 difriot_75_50 {
                gen const=1
				gen cutoff1=0.45
				gen cutoff2=0.75

x_ols latitude longitude cutoff1 cutoff2 share1830  const `lname'  $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots

drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

							
        }


/********************************************************************************************************************************************************************

Difference tests reported Table 2, panel B 


********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 


foreach lname of var constriots1 constriots10 constriots20 constriots30  constriots50  {
               
sureg (share1831   `lname' $baseline) (share1830  `lname' $baseline)
  test [share1831]`lname' = [share1830]`lname'
							
        }


