/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 


Table 3. Local Swing riots and the outcome of the 1831 and 1830 elections. Matching estimates.

Special programs used in this do-file

nmatch -- written by Abadie, Alberto, David Drukker, Jane Leber Herr, Guido W. Imbens, 2004. Implementing matching estimators for average treatment effects in Stata. The Stata Journal 4 (3), 290-311.

pscore -- written by Becker, Sascha O. and Ichino, Andrea, 2002. Estimation of Average Treatment Effects Based on Propensity Scores. The Stata Journal 2(4), 358-377.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Covariate matching results reported in Table 3, panel A, cols. 1 and 2. 


********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching  
predict pscore2

sort riottreat10
by riottreat10: summarize pscore2 riottreat10
 
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

nnmatch  share1831 riottreat10  $matching if (pscore2>low)&(pscore2<high), tc(att)  bias(bias) m(4) robust(4)  

nnmatch  share1831 riottreat10  $matching if (pscore2>low)&(pscore2<high), tc(att) ex(reform_1830 share1826) bias(bias) m(4) robust(4)


/********************************************************************************************************************************************************************

Covariate matching results reported in Table 3, panel B, col. 1 and 2. 


********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching  
predict pscore2

sort riottreat10
by riottreat10: summarize pscore2 riottreat10
 
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

nnmatch  share1830 riottreat10  $matching if (pscore2>low)&(pscore2<high), tc(att)  bias(bias) m(4) robust(4)  

nnmatch  share1830 riottreat10  $matching if (pscore2>low)&(pscore2<high), tc(att) ex(reform_1830 share1826) bias(bias) m(4) robust(4)


/********************************************************************************************************************************************************************

Propensity score matching results reported in Table 3, panel A, col. 1 and 2. 

NB: The bias correction is calculated with the boothstap procedure and the reported coefficient estimates cannot be reproduced exactly.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

pscore riottreat10   $matching ,  comsup pscore(pscore2) blockid(myblock) 

sort riottreat10
by riottreat10: summarize pscore2 riottreat10

gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/


attnw share1831 riottreat10  $matching  if (pscore2>low)&(pscore2<high), pscore(pscore2) boot reps(1000) dots   

attr share1831 riottreat10  $matching if (pscore2>low)&(pscore2<high), radius(0.05) pscore(pscore2)  boot reps(1000) dots   

attk share1831 riottreat10  $matching if (pscore2>low)&(pscore2<high),  epan bwidth(0.02) pscore(pscore2) boot reps(1000) dots  

atts share1831 riottreat10  $matching if (pscore2>low)&(pscore2<high), pscore(pscore2) blockid(myblock) boot reps(1000) dots   


/********************************************************************************************************************************************************************

Propensity score matching results reported in Table 3, panel B, col. 1 and 2. 

NB: The bias correction is calculated with the boothstap procedure and the reported coefficient estimates cannot be reproduced exactly.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

pscore riottreat10   $matching ,  comsup pscore(pscore2) blockid(myblock) 

sort riottreat10
by riottreat10: summarize pscore2 riottreat10

gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/


attnw share1830 riottreat10  $matching  if (pscore2>low)&(pscore2<high), pscore(pscore2) boot reps(1000) dots   

attr share1830 riottreat10  $matching if (pscore2>low)&(pscore2<high), radius(0.05) pscore(pscore2)  boot reps(1000) dots   

attk share1830 riottreat10  $matching if (pscore2>low)&(pscore2<high),  epan bwidth(0.02) pscore(pscore2) boot reps(1000) dots  

atts share1830 riottreat10  $matching if (pscore2>low)&(pscore2<high), pscore(pscore2) blockid(myblock) boot reps(1000) dots   

