/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table 4. Distance to Sevenoaks and the outcome of the 1831 and 1830 elections. Reduced form estimates.

Special programs used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Regression results reported in Table 4, panel A, cols. 1 to 3. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg share1831 road_dissevenoaks_const_km, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 share1831  const road_dissevenoaks_const_km, xreg(2) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 road_dissevenoaks_const_km $baseline $spatial, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 share1831  const road_dissevenoaks_const_km $baseline $spatial, xreg(22) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 road_dissevenoaks_const_km $baseline $spatial if county_id!=18, robust /*without Kent*/
display e(r2_a)  
drop if county_id==18
x_ols latitude longitude cutoff1 cutoff2 share1831  const road_dissevenoaks_const_km $baseline $spatial, xreg(22) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

/********************************************************************************************************************************************************************

Regression results reported in Table 4, panel B, cols. 1 to 3. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols report OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg share1830 road_dissevenoaks_const_km, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 share1830  const road_dissevenoaks_const_km, xreg(2) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1830 road_dissevenoaks_const_km $baseline $spatial, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 share1830  const road_dissevenoaks_const_km $baseline $spatial, xreg(22) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1830 road_dissevenoaks_const_km $baseline $spatial if  county_id!=18, robust /*without Kent*/
display e(r2_a)  
drop if county_id==18
x_ols latitude longitude cutoff1 cutoff2 share1830  const road_dissevenoaks_const_km $baseline $spatial, xreg(22) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

/********************************************************************************************************************************************************************

Probit results reported in Table 4, panel A, col. 4. 


********************************************************************************************************************************************************************/

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

prob reformer31 road_dissevenoaks_const_km $baseline_nu $spatial, cluster(consid)
mfx

/********************************************************************************************************************************************************************

Probit results reported in Table 4, panel B, col. 4. 


********************************************************************************************************************************************************************/

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

prob r_whig30 road_dissevenoaks_const_km $baseline_nu $spatial, cluster(consid)
mfx


