/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table 5. Local Swing riots and the outcome of the 1831 and 1830 elections. Instrumental variable estimates.

Special programs used in this do-file

x_gmm -- GMM with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.
x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

IV results reported in Table 5, panels A and B, cols. 1 to 3. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_gmm reports 2SLS standard errors and spatial standard errors. ivreg2 is used to calculate robust 2SLS standard errors and other relevant test statistics.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

ivreg2 share1831 (constriots10 = road_dissevenoaks_const_km), first robust
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots10 const road_dissevenoaks_const_km, xreg(2) inst(2) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1831 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial, first robust
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $spatial  const road_dissevenoaks_const_km $baseline $spatial , xreg(22) inst(22) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1831 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial if county_id!=18, first robust /*without Kent*/
drop if county_id==18
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $spatial  const road_dissevenoaks_const_km $baseline $spatial , xreg(22) inst(22) coord(2)
drop dis1
drop dis2
drop zubar*


/********************************************************************************************************************************************************************

Regression results reported in Table 5, panel C, cols. 1 to 3. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75


reg share1831 constriots10, robust
x_ols latitude longitude cutoff1 cutoff2 share1831  const  constriots10, xreg(2) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 constriots10  $baseline $spatial, robust
x_ols latitude longitude cutoff1 cutoff2 share1831  const  constriots10  $baseline $spatial, xreg(22) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 constriots10  $baseline $spatial if county_id!=18, robust /*without Kent*/
drop if county_id==18
x_ols latitude longitude cutoff1 cutoff2 share1831  const  constriots10  $baseline $spatial, xreg(22) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window


/********************************************************************************************************************************************************************

IV results reported in Table 5, panel D, cols. 1 to 3. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_gmm reports 2SLS standard errors and spatial standard errors. ivreg2 is used to calculate robust 2SLS standard errors and other relevant test statistics.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

ivreg2 share1830 (constriots10 = road_dissevenoaks_const_km), first robust
x_gmm latitude longitude cutoff1 cutoff2 share1830 const constriots10 const road_dissevenoaks_const_km, xreg(2) inst(2) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1830 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial, first robust
x_gmm latitude longitude cutoff1 cutoff2 share1830 const constriots10 $baseline $spatial  const road_dissevenoaks_const_km $baseline $spatial , xreg(22) inst(22) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1830 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial if county_id!=18, first robust /*without Kent*/
drop if county_id==18
x_gmm latitude longitude cutoff1 cutoff2 share1830 const constriots10 $baseline $spatial  const road_dissevenoaks_const_km $baseline $spatial , xreg(22) inst(22) coord(2)
drop dis1
drop dis2
drop zubar*


/********************************************************************************************************************************************************************

IV-Probit results reported in Table 5, panels A and B, col. 4. 

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

ivprobit reformer31 (constriots10 = road_dissevenoaks_const_km) $baseline_nu $spatial,  first cluster(consid)
mfx

/********************************************************************************************************************************************************************

Probit results reported in Table 5, panel C, col. 4.  

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

probit reformer31 constriots10 $baseline_nu $spatial, cluster(consid)
mfx

/********************************************************************************************************************************************************************

IV-Probit results reported in Table 5, panel D, col. 4. 

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

ivprobit r_whig30 (constriots10 = road_dissevenoaks_const_km) $baseline_nu $spatial,  first cluster(consid)
mfx
