/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table 6. Local Swing riots and the outcome of the 1831 election. Additional Placebo tests.

Special programs used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Regression results reported in Table 6, col 1. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_pre_reform.dta
global employment_1821 "h_index_1821 p_agriculture_1821 p_trade_1821 population_1821 density1821 "
global base_1826_swing "share1820 share1820_2 county university narrow  rottenindex_1826 " 

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg share1826 constriots10 $base_1826_swing $employment_1821, robust 
x_ols latitude longitude cutoff1 cutoff2 share1826 const constriots10  $base_1826_swing $employment_1821, xreg(13) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window




/********************************************************************************************************************************************************************

Regression results reported in Table 6, cols. 2 and 3. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_post_reform.dta

global demography_1831 "population_31 density_31 primary_1831 secondary_1831  h_index_31 " 

drop if sur_sharelibvotes35==.
drop if sur_sharelibvotes32==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg sur_sharelibvotes35 constriots10 sur_sharelibvotes32* county $demography_1831, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes35  const constriots10 sur_sharelibvotes32* county $demography_1831 , xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots

drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta

global demography_1861 "population_61 density_61 primary_1861 secondary_1861  h_index_61 "

drop if yes_share1867==.
drop if lib_share1866==.
drop if  con_share1866==.
drop if population_61==.
drop if density_61==.
drop if primary_1861==.
drop if secondary_1861==.
drop if h_index_61==.

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg yes_share1867 constriots10 lib_share1866 con_share1866 county $demography_1861, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 yes_share1867  const constriots10 lib_share1866 con_share1866 county $demography_1861 , xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots

drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window



/********************************************************************************************************************************************************************

Regression results reported in Table 6, col. 4. 

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global riots = "cum_food_riots cum_labour_riots"
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 

reg share1831 $riots $baseline,  robust cluster(county_id)
reg share1831 $riots $baseline,  robust 
display e(r2_a)

/********************************************************************************************************************************************************************

Regression results reported in Table 6, cols. 5 and 6. 

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global riots = "cum_food_riots cum_labour_riots"
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

reg constriots10 $riots, robust cluster(county_id)
reg constriots10 $riots, robust 
display e(r2_a)

reg constriots10 $riots road_dissevenoaks_const_km  $spatial,  robust cluster(county_id)
reg constriots10 $riots  road_dissevenoaks_const_km $spatial,  robust 
display e(r2_a)
