/********************************************************************************************************************************************************************
"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table 7. Local Swing riots and the outcome of the 1831 election. Alternative explanations for the Whig victory.

Special programs used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Regression results reported in Table 7. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg share1831 constriots10 $baseline if patronage4!=1, robust /*without the 14 treasure boroughs*/
display e(r2_a)
drop if patronage4==1
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10 $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global catpet "againstcatholics  forcatholics"
global reformpet "againstreform forreform"
global repression "special_commission share_death_deport" 
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg share1831 constriots10 $baseline $catpet againstslavery, robust 
display e(r2_a)
test (againstcatholics=0) (forcatholics=0) (againstslavery = 0)
x_ols latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $catpet againstslavery, xreg(20) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window


reg share1831 constriots10 $baseline $catpet againstslavery $reformpet, robust 
display e(r2_a)
test (againstreform =0) (forreform=0)
x_ols latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $catpet againstslavery $reformpet, xreg(22) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window


reg share1831 constriots10 $baseline $catpet againstslavery $reformpet gpoor_rate if gpoor_rate!=., cluster(county_id)
display e(r2_a)
drop if gpoor_rate==.
x_ols latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $catpet againstslavery $reformpet gpoor_rate, xreg(23) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global catpet "againstcatholics  forcatholics"
global reformpet "againstreform forreform"
global repression "special_commission share_death_deport"
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg share1831 constriots10 $baseline $catpet againstslavery $reformpet $repression, cluster(county_id)
display e(r2_a)
test (special_commission =0) (share_death_deport=0)
x_ols latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $catpet againstslavery $reformpet $repression, xreg(24) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

