
/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table S11. Local Swing riots and the outcome of the 1831 and 1830 elections. Covariate matching estimates - Randomization inference

Programs used in this do-file

The main code to implement the randomization inference procedure: 
  Bowers Jake, Fredrickson, Mark, Hansen, Ben, 2009. xbalance: Stata module to compute standardized differences for stratified comparisons via R. Statistical Software Components from Boston College, Department of Economics.
In addition, the implementation requires:
   R (http://cran.r-project.org) 
   The installation of RITools in R (Bowers, Jake, Hansen, Ben, 2006. RITools. Technical Report #436. Statistics Department, University of Michigan.)
   The installation in Stata of the rsource code (Newson, Roger, 2007, rsource: Stata module to run R from inside Stata using an R source file, Statistical Software Components from Boston College, Department of Economics. (new version 2014)).

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set more off

/********************************************************************************************************************************************************************

Table S11. Panel A.

********************************************************************************************************************************************************************/


cd $root/data
use data_const.dta

global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching  
predict pscore2

sort riottreat10
by riottreat10: summarize pscore2 riottreat10
 
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

global Rterm_path `"c:\Program Files\R\R-3.1.1\bin\R.exe"'
keep if university==0 & (pscore2>0)&(pscore2<1)
xbalance  riottreat10 pscore share1831  $matching 

clear

cd $root/data
use data_const.dta

global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching  
predict pscore2

sort riottreat10
by riottreat10: summarize pscore2 riottreat10
 
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

global Rterm_path `"c:\Program Files\R\R-3.1.1\bin\R.exe"'
keep if university==0 & (pscore2>low)&(pscore2<high)
xbalance  riottreat10 pscore share1831  $matching 

clear

/********************************************************************************************************************************************************************

Table S11. Panel B.

********************************************************************************************************************************************************************/

cd $root/data
use data_const.dta

global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching  
predict pscore2

sort riottreat10
by riottreat10: summarize pscore2 riottreat10
 
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

global Rterm_path `"c:\Program Files\R\R-3.1.1\bin\R.exe"'
keep if university==0 & (pscore2>0)&(pscore2<1)
xbalance  riottreat10 pscore share1830  $matching 

clear

cd $root/data
use data_const.dta

global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching  
predict pscore2

sort riottreat10
by riottreat10: summarize pscore2 riottreat10
 
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/


global Rterm_path `"c:\Program Files\R\R-3.1.1\bin\R.exe"'
keep if university==0 & (pscore2>low)&(pscore2<high)
xbalance  riottreat10 pscore share1830  $matching 


