/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table S13. Local Swing riots and the outcome of the 1830 election. Complete IV estimates for the first stage summarized in Panel D of Table 5.

Table S14. Local Swing riots and the outcome of the 1830 election. Complete Placebo IV estimates for the second stage summarized in Panel D of Table 5.

Table S15. Local Swing riots and the outcome of the 1831 election. Complete IV estimates for the first stage summarized in Panel B of Table 5.

Table S16. Local Swing riots and the outcome of the 1831 election. Complete IV estimates for the second stage summarized in Panel A of Table 5.

Table S17. Correlation between the structural characteristics of the English constituencies in 1831 and their distance to Sevenoaks.

Table S18. Local Swing riots and the outcome of the 1831 election. Reduced form and IV estimates controlling for Latitude and Longitude.

Non-authored programs used in this do-file

x_gmm -- GMM with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.
x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Table S13. Local Swing riots and the outcome of the 1830 election. Complete IV estimates for the first stage summarized in Panel D of Table 5.

Table S14. Local Swing riots and the outcome of the 1830 election. Complete Placebo IV estimates for the second stage summarized in Panel D of Table 5.


The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

Note: x_gmm reports 2SLS standard errors and spatial standard errors. ivreg2 is used to calculate robust 2SLS standard errors and other relevant test statistics.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

ivreg2 share1830 (constriots10 = road_dissevenoaks_const_km), first robust
x_gmm latitude longitude cutoff1 cutoff2 share1830 const constriots10 const road_dissevenoaks_const_km, xreg(2) inst(2) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1830 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial, first robust
x_gmm latitude longitude cutoff1 cutoff2 share1830 const constriots10 $baseline $spatial const road_dissevenoaks_const_km $baseline $spatial, xreg(22) inst(22) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1830 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial if county_id!=18, first robust
drop if county_id==18 /*excluded constituencies in Kent*/
x_gmm latitude longitude cutoff1 cutoff2 share1830 const constriots10 $baseline $spatial const road_dissevenoaks_const_km $baseline $spatial, xreg(22) inst(22) coord(2)
drop dis1
drop dis2
drop zubar*

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

ivprobit r_whig30 (constriots10 = road_dissevenoaks_const_km) $baseline_nu $spatial, first cluster(consid)
mfx


/********************************************************************************************************************************************************************

Table S15. Local Swing riots and the outcome of the 1831 election. Complete IV estimates for the first stage summarized in Panel B of Table 5.

Table S16. Local Swing riots and the outcome of the 1831 election. Complete IV estimates for the second stage summarized in Panel A of Table 5.


The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

Note: x_gmm reports 2SLS standard errors and spatial standard errors. ivreg2 is used to calculate robust 2SLS standard errors and other relevant test statistics.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

ivreg2 share1831 (constriots10 = road_dissevenoaks_const_km), first robust
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots10 const road_dissevenoaks_const_km, xreg(2) inst(2) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1831 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial, first robust
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $spatial const road_dissevenoaks_const_km $baseline $spatial, xreg(22) inst(22) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1831 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial if county_id!=18, first robust
drop if county_id==18 /*excluded constituencies in Kent*/
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $spatial const road_dissevenoaks_const_km $baseline $spatial, xreg(22) inst(22) coord(2)
drop dis1
drop dis2
drop zubar*

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

probit reformer31 constriots10 $baseline_nu $spatial, cluster(consid)
mfx


/********************************************************************************************************************************************************************

Table S17. Correlation between the structural characteristics of the English constituencies in 1831 and their distance to Sevenoaks.

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

Note: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global demographic "h_index1831 primary secondary tetitary"
global structure "population1831 density1831 economictrend1 economictrend2"
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg road_dissevenoaks_const_km $spatial, robust
display e(r2_a)

reg road_dissevenoaks_const_km $spatial $demographic, robust
display e(r2_a)

reg road_dissevenoaks_const_km $spatial $demographic $structure, robust
display e(r2_a)

/********************************************************************************************************************************************************************

Table S18. Local Swing riots and the outcome of the 1831 election. Reduced form and IV estimates controlling for Latitude and Longitude.

Panel A. 2SLS and IV-probit 

Panel B. First stage, cols. 2, 3 and 4.

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

Note: x_gmm reports 2SLS standard errors and spatial standard errors. ivreg2 is used to calculate robust 2SLS standard errors and other relevant test statistics.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"
global coordinates "longitude latitude"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

ivreg2 share1831 (constriots10 = road_dissevenoaks_const_km) $baseline $spatial $coordinates, first robust
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots10 $baseline $spatial $coordinates const road_dissevenoaks_const_km $baseline $spatial $coordinates, xreg(24) inst(24) coord(2)
drop dis1
drop dis2
drop zubar*

ivreg2 share1831 (constriots20 = road_dissevenoaks_const_km) $baseline $spatial $coordinates, first robust
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots20 $baseline $spatial $coordinates const road_dissevenoaks_const_km $baseline $spatial $coordinates, xreg(24) inst(24) coord(2)
drop dis1
drop dis2
drop zubar*

/*not reported in the tables but mentioned in footnote 34*/
ivreg2 share1831 (constriots30 = road_dissevenoaks_const_km) $baseline $spatial $coordinates, first robust
x_gmm latitude longitude cutoff1 cutoff2 share1831 const constriots30 $baseline $spatial $coordinates const road_dissevenoaks_const_km $baseline $spatial $coordinates, xreg(24) inst(24) coord(2)
drop dis1
drop dis2
drop zubar*

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"
global coordinates "longitude latitude"

ivprobit reformer31 (constriots10 = road_dissevenoaks_const_km) $baseline_nu $spatial $coordinates, first cluster(consid)
mfx

/********************************************************************************************************************************************************************

Table S18. Local Swing riots and the outcome of the 1831 election. Reduced form and IV estimates controlling for Latitude and Longitude.

Panel B. Reduced form, col 1.

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

Note: x_OLS reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"
global coordinates "longitude latitude"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg share1831 road_dissevenoaks_const_km $baseline $spatial $coordinates, robust
x_ols latitude longitude cutoff1 cutoff2 share1831  const road_dissevenoaks_const_km $baseline $spatial $coordinates, xreg(24) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window


/********************************************************************************************************************************************************************

Table S18. Local Swing riots and the outcome of the 1831 election. Reduced form and IV estimates controlling for Latitude and Longitude.

Panel C. Least squares and probit, cols. 2, 3 and 4.

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

Note: x_OLS reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"
global coordinates "longitude latitude"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg share1831 constriots10 $baseline $spatial $coordinates, robust
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10 $baseline $spatial $coordinates, xreg(24) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1831 constriots20 $baseline $spatial $coordinates, robust
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots20 $baseline $spatial $coordinates, xreg(24) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_seat.dta

global baseline_nu "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
global spatial "nearest_pc_km index1 market agg_type1 agg_type2"
global coordinates "longitude latitude"

probit reformer31 constriots10 $baseline_nu $spatial $coordinates, cluster(consid)
mfx

