/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table S19. Local Swing riots and the outcome of the elections in 1802, 1806, 1807, 1812, 1818, 1820 and 1826.

Non-authored program used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

clear
cd $root/data
use data_pre_reform.dta
global base_1802_swing "share1796* county university narrow  rottenindex_1802"
global base_1806_swing "share1802* county university narrow  rottenindex_1806"
global base_1807_swing "share1806* county university narrow  rottenindex_1807"
global employment_1801 "h_index_1801 p_agriculture_1801 p_trade_1801 population_1801 density1801"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
keep if density1801!=.

reg share1802 constriots10 $base_1802_swing $employment_1801, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1802 const constriots10 $base_1802_swing $employment_1801, xreg(13) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1806 constriots10 $base_1806_swing $employment_1801, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1806 const constriots10 $base_1806_swing $employment_1801, xreg(13) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1807 constriots10 $base_1807_swing $employment_1801, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1807 const constriots10 $base_1807_swing $employment_1801, xreg(13) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_pre_reform.dta
global base_1812_swing "share1807* county university narrow  rottenindex_1812"
global base_1818_swing "share1812* county university narrow  rottenindex_1818"
global base_1820_swing "share1818* county university narrow  rottenindex_1820"
global base_1826_swing "share1820* county university narrow  rottenindex_1826" 
global employment_1811 "h_index_1811 p_agriculture_1811 p_trade_1811 population_1811 density1811"
global employment_1821 "h_index_1821 p_agriculture_1821 p_trade_1821 population_1821 density1821"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg share1812 constriots10 $base_1812_swing $employment_1811, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1812 const constriots10 $base_1812_swing $employment_1811, xreg(13) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1818 constriots10 $base_1818_swing $employment_1811, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1818 const constriots10 $base_1818_swing $employment_1811, xreg(13) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1820 constriots10 $base_1820_swing $employment_1821, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1820 const constriots10 $base_1820_swing $employment_1821, xreg(13) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop epsilon
drop dis1
drop dis2
drop window

reg share1826 constriots10 $base_1826_swing $employment_1821, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1826 const constriots10 $base_1826_swing $employment_1821, xreg(13) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

