/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table S1. Test for mean differences between treated and control constituencies.

Table S5. Local Swing riots and the outcome of the 1831 election. Covariate matching estimates.

Table S6. Local Swing riots and the outcome of the 1830 election.  Placebo covariate matching estimates.

Table S7. Local Swing riots and the outcome of the 1831 election.
Covariate matching estimates with control constituencies in the bottom 28 percentile and treated constituencies in the top 50 percentile

Table S8. Local Swing riots and the outcome of the 1831 election. Propensity score matching estimates.

Table S9. Local Swing riots and the outcome of the 1830 election. Placebo propensity score matching estimates.

Table S10. Local Swing riots and the outcome of the 1831 election.
Propensity score matching estimates with Control constituencies in the bottom 28 percentile and treated constituencies in the top 50 percentile.

Table S12. Local Swing riots and the outcome of the 1831 election. Riots on the extensive margin and common support.

Non-authored programs used in this do-file

nmatch -- written by Abadie, Alberto, David Drukker, Jane Leber Herr, Guido W. Imbens, 2004.  Implementing matching estimators for average treatment effects in Stata. The Stata Journal 4 (3), 290-311.

pscore -- written by Becker, Sascha O. and Ichino, Andrea, 2002. Estimation of Average Treatment Effects Based on Propensity Scores. The Stata Journal 2(4), 358-377.

Note: The bias correction in the pscore procedure is calculated via bootstrap and cannot be reproduced exactly; neither can the bootstrapped standard errors. 
      However the differences in the size of the coefficients between runs of the do-file and our results should be minimal and the significance of the 
	  coefficients should not be affected. 

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Table S1. Test for mean differences between treated and control constituencies.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1


foreach lname of var   $matching share1831 constriots10 {
                summ  `lname'
				ttest  `lname', by(riottreat10) unequal
				
        }


/********************************************************************************************************************************************************************

Table S5. Local Swing riots and the outcome of the 1831 election. Covariate matching estimates.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching  
predict pscore2

sort riottreat10
by riottreat10: summarize pscore2 riottreat10
 
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

nnmatch  share1831 riottreat10  $matching if  (pscore2>0)&(pscore2<1), tc(att)    m(4)   robust(4)
nnmatch  share1831 riottreat10  $matching if  (pscore2>0)&(pscore2<1), tc(att)    m(4)  bias(bias)  robust(4)

nnmatch  share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(4)   robust(4)
nnmatch  share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(4)  bias(bias) robust(4)

nnmatch  share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)  ex(reform_1830 share1826)   m(4)   robust(4)
nnmatch  share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att) ex(reform_1830 share1826)  bias(bias) m(4)  robust(4)

nnmatch  share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(2)   robust(2)
nnmatch  share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(2)  bias(bias) robust(2)

nnmatch  share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)   m(1)   robust(1)
nnmatch  share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(1)  bias(bias) robust(1)

/********************************************************************************************************************************************************************

Table S6. Local Swing riots and the outcome of the 1830 election.  Placebo covariate matching estimates.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching  
predict pscore2

sort riottreat10
by riottreat10: summarize pscore2 riottreat10
 
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

nnmatch  share1830 riottreat10  $matching if  (pscore2>0)&(pscore2<1), tc(att)    m(4)   robust(4)
nnmatch  share1830 riottreat10  $matching if  (pscore2>0)&(pscore2<1), tc(att)    m(4)  bias(bias)  robust(4)

nnmatch  share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(4)   robust(4)
nnmatch  share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(4)  bias(bias) robust(4)

nnmatch  share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)  ex(reform_1830 share1826)   m(4)  robust(4)
nnmatch  share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att) ex(reform_1830 share1826)  bias(bias) m(4)   robust(4)

nnmatch  share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(2)   robust(2)
nnmatch  share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(2)  bias(bias) robust(2)

nnmatch  share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)   m(1)   robust(1)
nnmatch  share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high), tc(att)    m(1)  bias(bias) robust(1)


/********************************************************************************************************************************************************************

Table S7. Local Swing riots and the outcome of the 1831 election.
Covariate matching estimates with control constituencies in the bottom 28 percentile and treated constituencies in the top 50 percentile

Robustness check which drops constituencies in the second quartile, i.e. constituencies with riots in the range (1,5].

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

probit riottreat10 $matching if (constriots10<=1  | constriots10>5)
predict pscore3

sort riottreat10
by riottreat10: summarize pscore3 if (constriots10<=1  | constriots10>5) 

gen low3=0.3997 /*lower bound on common support*/ 
gen high3=0.904 /*upper bound on common support*/
   
nnmatch  share1831 riottreat10 $matching if  (constriots10<=1  | constriots10>5), tc(att)    m(4)   robust(4)
nnmatch  share1831 riottreat10 $matching if  (constriots10<=1  | constriots10>5), tc(att)    m(4)  bias(bias) robust(4)

nnmatch  share1831 riottreat10 $matching if  (pscore3>low3)&(pscore3<high3) & (constriots10<=1  | constriots10>5) , tc(att)    m(4)   robust(4)
nnmatch  share1831 riottreat10 $matching if  (pscore3>low3)&(pscore3<high3) & (constriots10<=1  | constriots10>5), tc(att)    m(4)  bias(bias) robust(4)

nnmatch  share1831 riottreat10 $matching if  (pscore3>low3)&(pscore3<high3) & (constriots10<=1  | constriots10>5) , ex(reform_1830 share1826) tc(att)    m(4)   robust(4)
nnmatch  share1831 riottreat10 $matching if  (pscore3>low3)&(pscore3<high3) & (constriots10<=1  | constriots10>5), ex(reform_1830 share1826) tc(att)    m(4)  bias(bias) robust(4)

nnmatch  share1831 riottreat10 $matching if  (pscore3>low3)&(pscore3<high3) & (constriots10<=1  | constriots10>5) , tc(att)    m(2)   robust(2)
nnmatch  share1831 riottreat10 $matching if  (pscore3>low3)&(pscore3<high3) & (constriots10<=1  | constriots10>5), tc(att)    m(2)  bias(bias) robust(2)

nnmatch  share1831 riottreat10 $matching if  (pscore3>low3)&(pscore3<high3) & (constriots10<=1  | constriots10>5) , tc(att)    m(1)   robust(1)
nnmatch  share1831 riottreat10 $matching if  (pscore3>low3)&(pscore3<high3) & (constriots10<=1  | constriots10>5), tc(att)    m(1)  bias(bias) robust(1)

/********************************************************************************************************************************************************************

Table S8. Local Swing riots and the outcome of the 1831 election. Propensity score matching estimates.

NB: The bias correction in the pscore procedure is calculated via boothstap and cannot be reproduced exactly; either can the bootstrapped standard errors.

********************************************************************************************************************************************************************/
clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

pscore riottreat10 $matching, comsup pscore(pscore2) blockid(myblock) 

sort riottreat10
by riottreat10: summarize pscore2 riottreat10

gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

attnw share1831 riottreat10 $matching  if (pscore2>low)&(pscore2<high), pscore(pscore2) boot reps(1000) dots   

attr share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high) , radius(0.05) pscore(pscore2)  boot reps(1000) dots   

attr share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high) , pscore(pscore2) boot reps(1000) dots   

attk share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high) ,  epan bwidth(0.02) pscore(pscore2) boot reps(1000) dots  

attk share1831 riottreat10  $matching if  (pscore2>low)&(pscore2<high) ,  epan bwidth(0.04) pscore(pscore2) boot reps(1000) dots  

atts share1831 riottreat10  $matching if (pscore2>low)&(pscore2<high), pscore(pscore2) blockid(myblock) boot reps(1000) dots   


/********************************************************************************************************************************************************************

Table S9. Local Swing riots and the outcome of the 1830 election. Placebo propensity score matching estimates.

NB: The bias correction in the pscore procedure is calculated via boothstap and cannot be reproduced exactly; either can the bootstrapped standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

pscore riottreat10   $matching ,  comsup pscore(pscore2) blockid(myblock) 

sort riottreat10
by riottreat10: summarize pscore2 riottreat10

gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/

attnw share1830 riottreat10  $matching  if (pscore2>low)&(pscore2<high), pscore(pscore2) boot reps(1000) dots   

attr share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high) , radius(0.05) pscore(pscore2)  boot reps(1000) dots   

attr share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high) , pscore(pscore2) boot reps(1000) dots   

attk share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high) ,  epan bwidth(0.02) pscore(pscore2) boot reps(1000) dots  

attk share1830 riottreat10  $matching if  (pscore2>low)&(pscore2<high) ,  epan bwidth(0.04) pscore(pscore2) boot reps(1000) dots  

atts share1830 riottreat10  $matching if (pscore2>low)&(pscore2<high), pscore(pscore2) blockid(myblock) boot reps(1000) dots   

/********************************************************************************************************************************************************************

Table S10. Local Swing riots and the outcome of the 1831 election.
Propensity score matching estimates with Control constituencies in the bottom 28 percentile and treated constituencies in the top 50 percentile

Robustness check which drops constituencies in the second quartile, i.e. constituencies with riots in the range (1,5].

NB: The bias correction in the pscore procedure is calculated via boothstap and cannot be reproduced exactly; either can the bootstrapped standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1

pscore riottreat10  $matching if (constriots10<=1 | constriots10>5),  pscore(mypscore) blockid(myblock)  

sort riottreat10
by riottreat10: summarize mypscore

gen low3=0.3997 /*lower bound on common support*/ 
gen high3=0.904 /*upper bound on common support*/

attnw share1831 riottreat10 $matching  if (constriots10<=1 | constriots10>5) & (mypscore>low4)&(mypscore<high4),   pscore(mypscore) boot reps(1000) dots   

attr share1831 riottreat10 $matching if (constriots10<=1 | constriots10>5) & (mypscore>low4)&(mypscore<high4)  , radius(0.05) pscore(mypscore) boot reps(1000)  dots   

attr share1831 riottreat10 $matching if (constriots10<=1 | constriots10>5) & (mypscore>low4)&(mypscore<high4)   , pscore(mypscore)  boot reps(1000) dots   

attk share1831 riottreat10 $matching if (constriots10<=1 | constriots10>5) & (mypscore>low4)&(mypscore<high4)   ,  epan bwidth(0.02) pscore(mypscore) boot reps(1000) dots  

attk share1831 riottreat10 $matching if (constriots10<=1 | constriots10>5) & (mypscore>low4)&(mypscore<high4)   ,  epan bwidth(0.04) pscore(mypscore)  boot reps(1000) dots  

atts share1831 riottreat10 $matching if (constriots10<=1 | constriots10>5) & (mypscore>low4)&(mypscore<high4) , pscore(mypscore) blockid(myblock) boot reps(1000) dots   

/********************************************************************************************************************************************************************

Table S12. Local Swing riots and the outcome of the 1831 election. Riots on the extensive margin and common support.

Panel A.

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
reg share1831 riottreat10 $baseline, robust
display e(r2_a)
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
x_ols latitude longitude cutoff1 cutoff2 share1831  const riottreat10 $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window


global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1
probit riottreat10 $matching  
predict pscore2
sort riottreat10
by riottreat10: summarize pscore2 riottreat10
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/
reg share1831 riottreat10  $matching if (pscore2>low)&(pscore2<high), robust
display e(r2_a)
keep if (pscore2>low)&(pscore2<high)
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
x_ols latitude longitude cutoff1 cutoff2 share1831  const riottreat10  $matching, xreg(16) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window


clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1
probit riottreat10 $matching  
predict pscore2
sort riottreat10
by riottreat10: summarize pscore2 riottreat10
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/
reg share1831 $matching if (pscore2>low)&(pscore2<high) & riottreat10 ==1, robust
predict pshare_t1
display e(r2_a)
reg share1831 $matching if (pscore2>low)&(pscore2<high) & riottreat10 ==0, robust
predict pshare_c1
display e(r2_a)
keep if (pscore2>low)&(pscore2<high)
ttest pshare_t1==pshare_c1 if (pscore2>low)&(pscore2<high), unpaired  unequal

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
probit riottreat10 $matching  
predict pscore2
sort riottreat10
by riottreat10: summarize pscore2 riottreat10
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/
reg share1831 constriots10 $baseline if  riottreat10==1 & (pscore2>low)&(pscore2<high), robust
display e(r2_a)
keep if riottreat10  == 1 & (pscore2>low)&(pscore2<high)
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
x_ols latitude longitude cutoff1 cutoff2 share1831  const constriots10 $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window


/********************************************************************************************************************************************************************

Table S12. Local Swing riots and the outcome of the 1831 election. Riots on the extensive margin and common support

Panel B.

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.


********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
reg share1830 riottreat10 $baseline, robust
display e(r2_a)
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
x_ols latitude longitude cutoff1 cutoff2 share1830  const riottreat10  $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window



global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1
probit riottreat10 $matching  
predict pscore2
sort riottreat10
by riottreat10: summarize pscore2 riottreat10
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/
reg share1830 riottreat10  $matching if (pscore2>low)&(pscore2<high), robust
display e(r2_a)
keep if (pscore2>low)&(pscore2<high)
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
x_ols latitude longitude cutoff1 cutoff2 share1830  const riottreat10  $matching, xreg(16) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window


clear
cd $root/data
use data_const.dta
global matching "share1826 share1826_2 reform_1830 county narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
drop if university==1
probit riottreat10 $matching  
predict pscore2
sort riottreat10
by riottreat10: summarize pscore2 riottreat10
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/
reg share1830 $matching if (pscore2>low)&(pscore2<high) & riottreat10 ==1, robust
predict pshare_t1
display e(r2_a)
reg share1830 $matching if (pscore2>low)&(pscore2<high) & riottreat10 ==0, robust
predict pshare_c1
display e(r2_a)
keep if (pscore2>low)&(pscore2<high) &  university==0
ttest pshare_t1==pshare_c1 if (pscore2>low)&(pscore2<high), unpaired  unequal

clear
cd $root/data
use data_const.dta
global baseline "share1826 share1826_2 reform_1830 county university narrow rottenindex h_index1831 primary secondary tetitary population1831 density1831 economictrend1 economictrend2" 
probit riottreat10 $matching  
predict pscore2
sort riottreat10
by riottreat10: summarize pscore2 riottreat10
gen low=0.375 /*lower bound on common support*/
gen high=0.920 /*upper bound on common support*/
reg share1830 constriots10 $baseline if  riottreat10 ==1 & (pscore2>low)&(pscore2<high), robust
display e(r2_a)
keep if riottreat10  == 1 & (pscore2>low)&(pscore2<high)
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
x_ols latitude longitude cutoff1 cutoff2 share1830  const constriots10  $baseline, xreg(17) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

