/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table S23. Local Swing riots and the outcome of the elections between the Great Reform Act and the Second Reform Act of 1867.

Non-authored program used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

Note: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

clear
cd $root/data
use data_post_reform.dta

global demography_1831 "population_31 density_31 primary_1831 secondary_1831 h_index_31" 
drop if sur_sharelibvotes35==.
drop if sur_sharelibvotes32==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg sur_sharelibvotes35 constriots10 sur_sharelibvotes32* county $demography_1831, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes35  const constriots10 sur_sharelibvotes32* county $demography_1831 , xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
global demography_1841 "population_41 density_41 primary_1841 secondary_1841 h_index_41"
drop if sur_sharelibvotes35==.
drop if sur_sharelibvotes37==.
drop if population_41==.
drop if density_41==.
drop if primary_1841==.
drop if secondary_1841==.
drop if h_index_41==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg sur_sharelibvotes37 constriots10 sur_sharelibvotes35* county $demography_1841, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes37  const constriots10 sur_sharelibvotes35* county $demography_1841, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
global demography_1841 "population_41 density_41 primary_1841 secondary_1841 h_index_41"
drop if sur_sharelibvotes41==.
drop if sur_sharelibvotes37==.
drop if population_41==.
drop if density_41==.
drop if primary_1841==.
drop if secondary_1841==.
drop if h_index_41==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg sur_sharelibvotes41 constriots10 sur_sharelibvotes37* county $demography_1841, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes41 const constriots10 sur_sharelibvotes37* county $demography_1841, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
global demography_1851 "population_51 density_51 primary_1851 secondary_1851  h_index_51"
drop if sur_sharelibvotes41==.
drop if sur_sharelibvotes47==.
drop if density_51==.
drop if primary_1851==.
drop if secondary_1851==.
drop if h_index_51==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg sur_sharelibvotes47 constriots10 sur_sharelibvotes41* county $demography_1851, robust
display e(r2_a) 
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes47 const constriots10 sur_sharelibvotes41* county $demography_1851, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
global demography_1851 "population_51 density_51 primary_1851 secondary_1851  h_index_51"
drop if sur_sharelibvotes52==.
drop if sur_sharelibvotes47==.
drop if density_51==.
drop if primary_1851==.
drop if secondary_1851==.
drop if h_index_51==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg sur_sharelibvotes52 constriots10 sur_sharelibvotes47* county $demography_1851, robust
display e(r2_a) 
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes52 const constriots10 sur_sharelibvotes47* county $demography_1851, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
global demography_1861 "population_61 density_61 primary_1861 secondary_1861  h_index_61"
drop if sur_sharelibvotes52==.
drop if sur_sharelibvotes57==.
drop if population_61==.
drop if density_61==.
drop if primary_1861==.
drop if secondary_1861==.
drop if h_index_61==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg sur_sharelibvotes57 constriots10 sur_sharelibvotes52* county $demography_1861, robust
display e(r2_a) 
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes57  const constriots10 sur_sharelibvotes52* county $demography_1861, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
global demography_1861 "population_61 density_61 primary_1861 secondary_1861  h_index_61"
drop if sur_sharelibvotes59==.
drop if sur_sharelibvotes57==.
drop if population_61==.
drop if density_61==.
drop if primary_1861==.
drop if secondary_1861==.
drop if h_index_61==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg sur_sharelibvotes59 constriots10 sur_sharelibvotes57* county $demography_1861, robust
display e(r2_a) 
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes59 const constriots10 sur_sharelibvotes57* county $demography_1861, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
global demography_1861 "population_61 density_61 primary_1861 secondary_1861  h_index_61"
drop if sur_sharelibvotes59==.
drop if sur_sharelibvotes65==.
drop if population_61==.
drop if density_61==.
drop if primary_1861==.
drop if secondary_1861==.
drop if h_index_61==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg sur_sharelibvotes65 constriots10 sur_sharelibvotes59* county $demography_1861, robust
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 sur_sharelibvotes65  const constriots10 sur_sharelibvotes59* county $demography_1861, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window


