/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table S24. Local Swing riots and the support for the Second Reform Act.

Non-authored program used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off


/********************************************************************************************************************************************************************

Least squares, results reported in Table S24, panel A. 

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

Note: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_post_reform.dta
drop if yes_share1866==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg yes_share1866 constriots10, robust 
display e(r2_a) 
x_ols latitude longitude cutoff1 cutoff2 yes_share1866  const constriots10, xreg(2) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
drop if yes_share1866==.
drop if lib_share1866==.
drop if  con_share1866==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg yes_share1866 constriots10 lib_share1866 con_share1866, robust 
display e(r2_a) 
x_ols latitude longitude cutoff1 cutoff2 yes_share1866 const constriots10 lib_share1866 con_share1866, xreg(4) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
global demography_1861 "population_61 density_61 primary_1861 secondary_1861 h_index_61"
drop if yes_share1866==.
drop if lib_share1866==.
drop if  con_share1866==.
drop if population_61==.
drop if density_61==.
drop if primary_1861==.
drop if secondary_1861==.
drop if h_index_61==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg yes_share1866 constriots10 lib_share1866 con_share1866 county $demography_1861, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 yes_share1866  const constriots10 lib_share1866 con_share1866 county $demography_1861, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
drop if yes_share1867==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg yes_share1867 constriots10, robust 
display e(r2_a) 
x_ols latitude longitude cutoff1 cutoff2 yes_share1867 const constriots10, xreg(2) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window

clear
cd $root/data
use data_post_reform.dta
drop if yes_share1867==.
drop if lib_share1866==.
drop if  con_share1866==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg yes_share1867 constriots10 lib_share1866 con_share1866, robust 
display e(r2_a) 
x_ols latitude longitude cutoff1 cutoff2 yes_share1867 const constriots10 lib_share1866 con_share1866, xreg(4) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window


clear
cd $root/data
use data_post_reform.dta
global demography_1861 "population_61 density_61 primary_1861 secondary_1861 h_index_61"
drop if yes_share1867==.
drop if lib_share1866==.
drop if  con_share1866==.
drop if population_61==.
drop if density_61==.
drop if primary_1861==.
drop if secondary_1861==.
drop if h_index_61==.
gen const=1
gen cutoff1=0.45
gen cutoff2=0.75
reg yes_share1867 constriots10 lib_share1866 con_share1866 county $demography_1861, robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 yes_share1867  const constriots10 lib_share1866 con_share1866 county $demography_1861, xreg(10) coord(2)
matrix bb = e(b)
matrix v_dep = vecdiag(cov_dep)
scalar coef_riots = bb[1,2]
scalar se_riots = sqrt(v_dep[1,2])
display coef_riots/se_riots
drop const 
drop cutoff1 
drop cutoff2
drop epsilon
drop dis1
drop dis2
drop window


/********************************************************************************************************************************************************************

Fractional estimator, results reported in Table S24, panel B. 

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_post_reform.dta
global demography_1861 "population_61 density_61 primary_1861 secondary_1861 h_index_61"
glm  yes_share1866 constriots10,  fam(bin) link(logit) vce(robust) 
glm  yes_share1866 constriots10 lib_share1866 con_share1866, fam(bin) link(logit) vce(robust) 
glm  yes_share1866 constriots10 lib_share1866 con_share1866 county $demography_1861, fam(bin) link(logit) vce(robust)   
glm  yes_share1867 constriots10, fam(bin) link(logit) vce(robust)  
glm  yes_share1867 constriots10 lib_share1866 con_share1866, fam(bin) link(logit) vce(robust) 
glm  yes_share1867 constriots10 lib_share1866 con_share1866 county $demography_1861, fam(bin) link(logit) vce(robust)    
