/********************************************************************************************************************************************************************

"Democratization under the threat of revolution: evidence from the Great Reform Act of 1832" 

Table S2. Local Swing riots and the outcome of the 1831 election. Probit estimates of the likelihood that a Whig was elected to a seat.

Table S3. Local Swing riots and the outcome of the 1831 election. Fractional Estimator.

Table S4. Local Swing riots and the outcome of the 1830 election. Placebo results corresponding to Table 1.
 

Non-authored programs used in this do-file

x_ols -- OLS with spatial standard errors created by Conley, Timothy G. 1999. GMM Estimation with Cross Sectional Dependence. Journal of Econometrics 92 (1), 1-45.

********************************************************************************************************************************************************************/

global root "{Insert Root Directory}"

set matsize 11000 
clear all
set mem 400m
set more off

/********************************************************************************************************************************************************************

Table S2. Local Swing riots and the outcome of the 1831 election. Probit estimates of the likelihood that a Whig was elected to a seat.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_seat.dta

global base_nu "county narrow rottenindex" 
global reform "share1826 share1826_2 reform_1830"
global demographic "h_index1831 primary secondary tetitary"
global structure "population1831 density1831 economictrend1 economictrend2 "
global sign_nu "county rottenindex share1826 reform_1830 economictrend2"

prob reformer31 constriots10, cluster(consid)
mfx

prob reformer31 constriots10 $reform, cluster(consid)
mfx

prob reformer31 constriots10 $reform $base_nu, cluster(consid)
mfx

prob reformer31 constriots10 $reform $base_nu $demographic, cluster(consid)
mfx

prob reformer31 constriots10 $reform $base_nu $demographic $structure, cluster(consid)
mfx

prob reformer31 constriots10 $sign_nu, cluster(consid)
mfx

/********************************************************************************************************************************************************************

Table S3. Local Swing riots and the outcome of the 1831 election. Fractional Estimator.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta
gen share1831_01 = share1831/100 /*redefine share1831 to be a share*/

global base_nu "county narrow rottenindex" 
global reform "share1826 share1826_2 reform_1830"
global demographic "h_index1831 primary secondary tetitary"
global structure "population1831 density1831 economictrend1 economictrend2 "
global sign_nu "county university rottenindex share1826 reform_1830 economictrend2"

glm share1831_01 constriots10,  fam(bin) link(probit)  robust 

glm share1831_01 constriots10 $reform,  fam(bin) link(probit)  robust 

glm share1831_01 constriots10 $reform $base_nu,  fam(bin) link(probit)  robust 

glm share1831_01 constriots10 $reform $base_nu $demographic,  fam(bin) link(probit)  robust 

glm share1831_01 constriots10 $reform $base_nu $demographic $structure,  fam(bin) link(probit)  robust 

glm share1831_01 constriots10 $sign_nu,  fam(bin) link(probit)  robust 


/********************************************************************************************************************************************************************

Table S4. Local Swing riots and the outcome of the 1830 election. Placebo results corresponding to Table 1.

Panel A

The cutoff values for the spatial standard errors are
					50Km	
Latitude  cutoff	0.45    
Longitude cutoff	0.75    

NB: x_ols reports OLS standard errors and spatial standard errors. reg is used to calculate White robust standard errors.

********************************************************************************************************************************************************************/

clear
cd $root/data
use data_const.dta

global base "county university narrow rottenindex" 
global reform "share1826 share1826_2 reform_1830"
global demographic "h_index1831 primary secondary tetitary"
global structure "population1831 density1831 economictrend1 economictrend2 "
global sign "county university rottenindex share1826 reform_1830 economictrend2"

gen const=1
gen cutoff1=0.45
gen cutoff2=0.75

reg share1830 constriots10,  robust
display e(r2_a)  
x_ols latitude longitude cutoff1 cutoff2 share1830  const constriots10 , xreg(2) coord(2)
drop epsilon
drop dis1
drop dis2
drop window

reg share1830 constriots10 $reform, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1830  const constriots10 $reform , xreg(5) coord(2)
drop epsilon
drop dis1
drop dis2
drop window

reg share1830 constriots10 $reform $base, robust
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1830  const constriots10 $reform $base, xreg(9) coord(2)
drop epsilon
drop dis1
drop dis2
drop window


reg share1830 constriots10 $reform $base $demographic, robust
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1830  const constriots10 $reform $base $demographic, xreg(13) coord(2)
drop epsilon
drop dis1
drop dis2
drop window

reg share1830 constriots10 $reform $base $demographic $structure, robust  
display e(r2_a)
test primary secondary tetitary
x_ols latitude longitude cutoff1 cutoff2 share1830  const constriots10 $reform $base $structure $demographic, xreg(17) coord(2)
drop epsilon
drop dis1
drop dis2
drop window

reg share1830 constriots10 $sign, robust 
display e(r2_a)
x_ols latitude longitude cutoff1 cutoff2 share1830  const constriots10 $sign, xreg(8) coord(2)
drop epsilon
drop dis1
drop dis2
drop window


/********************************************************************************************************************************************************************

Table S4. Local Swing riots and the outcome of the 1830 election. Placebo results corresponding to Table 1.

Panel B


********************************************************************************************************************************************************************/

clear
cd $root/data
use data_seat.dta

global base_nu "county narrow rottenindex" 
global reform "share1826 share1826_2 reform_1830"
global demographic "h_index1831 primary secondary tetitary"
global structure "population1831 density1831 economictrend1 economictrend2"
global sign_nu "county rottenindex share1826 reform_1830 economictrend2"

prob r_whig30 constriots10, cluster(consid)
mfx

prob r_whig30 constriots10 $reform, cluster(consid)
mfx

prob r_whig30 constriots10 $reform $base_nu, cluster(consid)
mfx

prob r_whig30 constriots10 $reform $base_nu $demographic, cluster(consid)
mfx

prob r_whig30 constriots10 $reform $base_nu $demographic $structure, cluster(consid)
mfx

prob r_whig30 constriots10 $sign_nu, cluster(consid)
mfx
